==> dojo-1.9.4.tgz: package/cldr/nls/pt/gregorian.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Dia da semana",
	"dateFormatItem-yQQQ": "y QQQ",
	"dateFormatItem-yMEd": "E, dd/MM/y",
	"dateFormatItem-GyMMMEd": "E, d 'de' MMM 'de' y G",
	"dateFormatItem-MMMEd": "E, d 'de' MMM",
	"eraNarrow": [
		"a.C.",
		"d.C."
	],
	"dateFormatItem-yMM": "MM/y",
	"dayPeriods-format-wide-morning": "manhã",
	"days-format-short": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"dateFormat-long": "d 'de' MMMM 'de' y",
	"months-format-wide": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro",
		"novembro",
		"dezembro"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE, d 'de' MMMM 'de' y",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-abbr-am": "AM",
	"dayPeriods-format-wide-noon": "meio-dia",
	"dateFormatItem-yMd": "dd/MM/y",
	"field-era": "Era",
	"dateFormatItem-yM": "MM/y",
	"months-standAlone-wide": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro",
		"novembro",
		"dezembro"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"dateFormatItem-yQQQQ": "y QQQQ",
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "Ano",
	"dateFormatItem-yMMM": "MMM 'de' y",
	"field-hour": "Hora",
	"dateFormatItem-MMdd": "dd/MM",
	"months-format-abbr": [
		"jan",
		"fev",
		"mar",
		"abr",
		"mai",
		"jun",
		"jul",
		"ago",
		"set",
		"out",
		"nov",
		"dez"
	],
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-day-relative+0": "Hoje",
	"field-day-relative+1": "Amanhã",
	"dateFormatItem-GyMMMd": "d 'de' MMM 'de' y G",
	"field-day-relative+2": "Depois de amanhã",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"jan",
		"fev",
		"mar",
		"abr",
		"mai",
		"jun",
		"jul",
		"ago",
		"set",
		"out",
		"nov",
		"dez"
	],
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-standAlone-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-HHmmss": "HH:mm:ss",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"domingo",
		"segunda-feira",
		"terça-feira",
		"quarta-feira",
		"quinta-feira",
		"sexta-feira",
		"sábado"
	],
	"timeFormat-medium": "HH:mm:ss",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"eraAbbr": [
		"a.C.",
		"d.C."
	],
	"field-minute": "Minuto",
	"field-dayperiod": "Período do dia",
	"days-standAlone-abbr": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"dayPeriods-format-wide-night": "noite",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "Ontem",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"dayPeriods-format-narrow-am": "a",
	"field-day-relative+-2": "Anteontem",
	"dateFormatItem-MMMd": "d 'de' MMM",
	"dateFormatItem-MEd": "E, dd/MM",
	"dateTimeFormat-full": "{1} {0}",
	"field-day": "Dia",
	"days-format-wide": [
		"domingo",
		"segunda-feira",
		"terça-feira",
		"quarta-feira",
		"quinta-feira",
		"sexta-feira",
		"sábado"
	],
	"field-zone": "Fuso",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "Ano passado",
	"field-month-relative+-1": "Mês passado",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-format-abbr-pm": "PM",
	"days-format-abbr": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"eraNames": [
		"Antes de Cristo",
		"Ano do Senhor"
	],
	"dateFormatItem-yMMMd": "d 'de' MMM 'de' y",
	"days-format-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"days-standAlone-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Mês",
	"dateFormatItem-HHmm": "HH:mm",
	"dayPeriods-format-wide-am": "AM",
	"dateFormat-short": "dd/MM/yy",
	"dayPeriods-format-wide-afternoon": "tarde",
	"field-second": "Segundo",
	"dateFormatItem-yMMMEd": "E, d 'de' MMM 'de' y",
	"field-month-relative+0": "Este mês",
	"field-month-relative+1": "Próximo mês",
	"dateFormatItem-Ed": "E, d",
	"field-week": "Semana",
	"dateFormat-medium": "dd/MM/y",
	"field-year-relative+0": "Este ano",
	"field-week-relative+-1": "Semana passada",
	"field-year-relative+1": "Próximo ano",
	"dayPeriods-format-narrow-pm": "p",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM 'de' y G",
	"field-week-relative+0": "Esta semana",
	"field-week-relative+1": "Próxima semana"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/pt/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E, h:mm a",
	"days-standAlone-short": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "agora",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Dia da semana",
	"dateFormatItem-yQQQ": "y QQQ",
	"dateFormatItem-yMEd": "E, dd/MM/y",
	"field-wed-relative+0": "esta quarta-feira",
	"field-wed-relative+1": "próxima quarta-feira",
	"dateFormatItem-GyMMMEd": "E, d 'de' MMM 'de' y G",
	"dateFormatItem-MMMEd": "E, d 'de' MMM",
	"eraNarrow": [
		"a.C.",
		"d.C."
	],
	"dateFormatItem-yMM": "MM/y",
	"field-tue-relative+-1": "terça-feira passada",
	"dayPeriods-format-wide-morning": "manhã",
	"days-format-short": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"dateFormat-long": "d 'de' MMMM 'de' y",
	"field-fri-relative+-1": "sexta-feira passada",
	"field-wed-relative+-1": "quarta-feira passada",
	"months-format-wide": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro",
		"novembro",
		"dezembro"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE, d 'de' MMMM 'de' y",
	"field-thu-relative+-1": "quinta-feira passada",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-abbr-am": "AM",
	"dayPeriods-format-wide-noon": "meio-dia",
	"dateFormatItem-yMd": "dd/MM/y",
	"field-era": "Era",
	"dateFormatItem-yM": "MM/y",
	"months-standAlone-wide": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro",
		"novembro",
		"dezembro"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"dateFormatItem-yQQQQ": "y QQQQ",
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "Ano",
	"dateFormatItem-yMMM": "MMM 'de' y",
	"field-hour": "Hora",
	"dateFormatItem-MMdd": "dd/MM",
	"months-format-abbr": [
		"jan",
		"fev",
		"mar",
		"abr",
		"mai",
		"jun",
		"jul",
		"ago",
		"set",
		"out",
		"nov",
		"dez"
	],
	"field-sat-relative+0": "este sábado",
	"field-sat-relative+1": "próximo sábado",
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-day-relative+0": "hoje",
	"field-thu-relative+0": "esta quinta-feira",
	"field-day-relative+1": "amanhã",
	"field-thu-relative+1": "próxima quinta-feira",
	"dateFormatItem-GyMMMd": "d 'de' MMM 'de' y G",
	"field-day-relative+2": "depois de amanhã",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"jan",
		"fev",
		"mar",
		"abr",
		"mai",
		"jun",
		"jul",
		"ago",
		"set",
		"out",
		"nov",
		"dez"
	],
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-standAlone-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-HHmmss": "HH:mm:ss",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"domingo",
		"segunda-feira",
		"terça-feira",
		"quarta-feira",
		"quinta-feira",
		"sexta-feira",
		"sábado"
	],
	"timeFormat-medium": "HH:mm:ss",
	"field-sun-relative+0": "este domingo",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "próximo domingo",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"eraAbbr": [
		"a.C.",
		"d.C."
	],
	"field-minute": "Minuto",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"dayPeriods-format-wide-night": "noite",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "ontem",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"dayPeriods-format-narrow-am": "a",
	"field-day-relative+-2": "anteontem",
	"dateFormatItem-MMMd": "d 'de' MMM",
	"dateFormatItem-MEd": "E, dd/MM",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "esta sexta-feira",
	"field-fri-relative+1": "próxima sexta-feira",
	"field-day": "Dia",
	"days-format-wide": [
		"domingo",
		"segunda-feira",
		"terça-feira",
		"quarta-feira",
		"quinta-feira",
		"sexta-feira",
		"sábado"
	],
	"field-zone": "Fuso horário",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "ano passado",
	"field-month-relative+-1": "mês passado",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-format-abbr-pm": "PM",
	"days-format-abbr": [
		"dom",
		"seg",
		"ter",
		"qua",
		"qui",
		"sex",
		"sáb"
	],
	"eraNames": [
		"Antes de Cristo",
		"Ano do Senhor"
	],
	"dateFormatItem-yMMMd": "d 'de' MMM 'de' y",
	"days-format-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"days-standAlone-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Mês",
	"dateFormatItem-HHmm": "HH:mm",
	"field-tue-relative+0": "esta terça-feira",
	"field-tue-relative+1": "próxima terça-feira",
	"dayPeriods-format-wide-am": "AM",
	"dateFormatItem-EHm": "E, HH:mm",
	"field-mon-relative+0": "esta segunda-feira",
	"field-mon-relative+1": "próxima segunda-feira",
	"dateFormat-short": "dd/MM/yy",
	"dayPeriods-format-wide-afternoon": "tarde",
	"dateFormatItem-EHms": "E, HH:mm:ss",
	"dateFormatItem-Ehms": "E, h:mm:ss a",
	"field-second": "Segundo",
	"field-sat-relative+-1": "sábado passado",
	"dateFormatItem-yMMMEd": "E, d 'de' MMM 'de' y",
	"field-sun-relative+-1": "domingo passado",
	"field-month-relative+0": "este mês",
	"field-month-relative+1": "próximo mês",
	"dateFormatItem-Ed": "E, d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Semana",
	"dateFormat-medium": "d 'de' MMM 'de' y",
	"field-year-relative+0": "este ano",
	"field-week-relative+-1": "semana passada",
	"field-year-relative+1": "próximo ano",
	"dayPeriods-format-narrow-pm": "p",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM 'de' y G",
	"field-mon-relative+-1": "segunda-feira passada",
	"field-week-relative+0": "esta semana",
	"field-week-relative+1": "próxima semana"
}
//end v1.x content
);
